This folder contains a very small subset of the robot models shipped with

ARTE: A robotics toolbox for education, by Arturo Gil
[http://arvc.umh.es/arte/index_en.html](http://arvc.umh.es/arte/index_en.html).

You can obtain additional models from the full ARTE download, the full list is
available [here](http://arvc.umh.es/arte/supported_robots.html)

Download and unzip the robot models from ARTE, then move the arte/robots to a new folder below this one named `MANUFACTUER/MODEL` which contains a bunch of stl files named `link0.stl`, `link1.stl` etc. 

You will also need to create a class in the parent folder
